EsEventType

Enum EsEventType 

#[repr(u32)]
pub enum EsEventType {
Show 125 variants AuthExec = 0, AuthOpen = 1, AuthKExtLoad = 2, AuthMMap = 3, AuthMProtect = 4, AuthMount = 5, AuthRename = 6, AuthSignal = 7, AuthUnlink = 8, NotifyExec = 9, NotifyOpen = 10, NotifyFork = 11, NotifyClose = 12, NotifyCreate = 13, NotifyExchangeData = 14, NotifyExit = 15, NotifyGetTask = 16, NotifyKExtLoad = 17, NotifyKExtUnload = 18, NotifyLink = 19, NotifyMMap = 20, NotifyMProtect = 21, NotifyMount = 22, NotifyUnmount = 23, NotifyIOKitOpen = 24, NotifyRename = 25, NOtifySetAttrList = 26, NotifySetExtAttr = 27, NotifySetFlags = 28, NotifySetMode = 29, NotifySetOwner = 30, NotifySignal = 31, NotifyUnlink = 32, NotifyWrite = 33, AuthFileProviderMaterialize = 34, NotifyFileProviderMaterialize = 35, AuthFileProviderUpdate = 36, NotifyFileProviderUpdate = 37, AuthReadLink = 38, NotifyReadLink = 39, AuthTruncate = 40, NotifyTruncate = 41, AuthLink = 42, NotifyLookup = 43, AuthCreate = 44, AuthSetAttrList = 45, AuthSetExtAttr = 46, AuthSetFlags = 47, AuthSetMode = 48, AuthSetOwner = 49, AuthChdir = 50, NotifyChdir = 51, AuthGetAttrList = 52, NotifyGetAttrList = 53, NotifyStat = 54, NotifyAccess = 55, AuthChroot = 56, NotifyChroot = 57, AuthUtimes = 58, NotifyUtimes = 59, AuthClone = 60, NotifyClone = 61, NotifyFcntl = 62, AuthGetExtAttr = 63, NotifyGetExtAttr = 64, AuthListenExtAttr = 65, NotifyListenExtAttr = 66, AuthReadDir = 67, NotifyReadDir = 68, AuthDeleteExtAttr = 69, NotifyDeleteExtAttr = 70, AuthFsGetPath = 71, NotifyFsGetPath = 72, NotifyDup = 73, AuthSetTime = 74, NotifySetTime = 75, NotifyUIPCBind = 76, AuthUIPCBind = 77, NotifyUIPCConnect = 78, AuthUIPCConnect = 79, AuthExchangeData = 80, AuthSetACL = 81, NotifySetACL = 82, NotifyPTYGrant = 83, NotifyPTYClose = 84, AuthProcCheck = 85, NotifyProcCheck = 86, AuthGetTask = 87, AuthSearchFs = 88, NotifySearchFs = 89, AuthFcntl = 90, AuthIOKitOpen = 91, AuthProcSuspendResume = 92, NotifyProcSuspendResume = 93, NotifyCsInvalidDate = 94, NotifyGetTaskName = 95, NotfiyTrace = 96, NotifyRemoteThreadCreate = 97, AuthRemount = 98, NotifyRemount = 99, AuthGetTaskRead = 100, NotifyGetTaskRead = 101, NotifyGetTaskInspect = 102, NotifySetUid = 103, NotifySetGid = 104, NotifySetEUid = 105, NotifySetEGuid = 106, NotifySetREUid = 107, NotifySetREGuid = 108, AuthCopyFile = 109, NotifyCopyFile = 110, NotifyAuthentication = 111, NotifyXPMalwareDetected = 112, NotifyXPMalwareRemediated = 113, NotifyLWSessionLogin = 114, NotifyLWSessionLogout = 115, NotifyLWSessionLock = 116, NotifyLWSessionUnlock = 117, NotifyScreenSharingAttach = 118, AuthScreenSharingAttach = 119, NotifyOpenSSHLogin = 120, NotifyOpenSSHLogout = 121, NotifyBTMLaunchItemAdd = 122, NotifyBTMLaunchItemRemove = 123, Last = 124,
}
All the events supported by Endpoint Security, see more

README: While all events are supported by the crate, only few have EsEventData types. If one of the event your interested in is missing, please send us a PR or open an issue on github.

Variants



AuthExec = 0



AuthOpen = 1



AuthKExtLoad = 2



AuthMMap = 3



AuthMProtect = 4



AuthMount = 5



AuthRename = 6



AuthSignal = 7



NotifyExec = 9



NotifyOpen = 10



NotifyFork = 11



NotifyClose = 12



NotifyCreate = 13



NotifyExchangeData = 14



NotifyExit = 15



NotifyGetTask = 16



NotifyKExtLoad = 17



NotifyKExtUnload = 18



NotifyMMap = 20



NotifyMProtect = 21



NotifyMount = 22



NotifyUnmount = 23



NotifyIOKitOpen = 24



NotifyRename = 25



NOtifySetAttrList = 26



NotifySetExtAttr = 27



NotifySetFlags = 28



NotifySetMode = 29



NotifySetOwner = 30



NotifySignal = 31



NotifyWrite = 33



AuthFileProviderMaterialize = 34



NotifyFileProviderMaterialize = 35



AuthFileProviderUpdate = 36



NotifyFileProviderUpdate = 37



AuthTruncate = 40



NotifyTruncate = 41



NotifyLookup = 43



AuthCreate = 44



AuthSetAttrList = 45



AuthSetExtAttr = 46



AuthSetFlags = 47



AuthSetMode = 48



AuthSetOwner = 49



AuthChdir = 50



NotifyChdir = 51



AuthGetAttrList = 52



NotifyGetAttrList = 53



NotifyStat = 54



NotifyAccess = 55



AuthChroot = 56



NotifyChroot = 57



AuthUtimes = 58



NotifyUtimes = 59



AuthClone = 60



NotifyClone = 61



NotifyFcntl = 62



AuthGetExtAttr = 63



NotifyGetExtAttr = 64



AuthListenExtAttr = 65



NotifyListenExtAttr = 66



AuthReadDir = 67



NotifyReadDir = 68



AuthDeleteExtAttr = 69



NotifyDeleteExtAttr = 70



AuthFsGetPath = 71



NotifyFsGetPath = 72



NotifyDup = 73



AuthSetTime = 74



NotifySetTime = 75



NotifyUIPCBind = 76



AuthUIPCBind = 77



NotifyUIPCConnect = 78



AuthUIPCConnect = 79



AuthExchangeData = 80



AuthSetACL = 81



NotifySetACL = 82



NotifyPTYGrant = 83



NotifyPTYClose = 84



AuthProcCheck = 85



NotifyProcCheck = 86



AuthGetTask = 87



AuthSearchFs = 88



NotifySearchFs = 89



AuthFcntl = 90



AuthIOKitOpen = 91



AuthProcSuspendResume = 92



NotifyProcSuspendResume = 93



NotifyCsInvalidDate = 94



NotifyGetTaskName = 95



NotfiyTrace = 96



NotifyRemoteThreadCreate = 97



AuthRemount = 98



NotifyRemount = 99



AuthGetTaskRead = 100



NotifyGetTaskRead = 101



NotifyGetTaskInspect = 102



NotifySetUid = 103



NotifySetGid = 104



NotifySetEUid = 105



NotifySetEGuid = 106



NotifySetREUid = 107



NotifySetREGuid = 108



AuthCopyFile = 109



NotifyCopyFile = 110



NotifyAuthentication = 111



NotifyXPMalwareDetected = 112



NotifyXPMalwareRemediated = 113



NotifyLWSessionLogin = 114



NotifyLWSessionLogout = 115



NotifyLWSessionLock = 116



NotifyLWSessionUnlock = 117



NotifyScreenSharingAttach = 118



AuthScreenSharingAttach = 119



NotifyOpenSSHLogin = 120



NotifyOpenSSHLogout = 121



NotifyBTMLaunchItemAdd = 122



NotifyBTMLaunchItemRemove = 123



Last = 124